@@ -2,7 +2,7 @@
 from masoniteorm.models import Model
 from masoniteorm.scopes import SoftDeletesMixin
 from masonite.authentication import Authenticates
-from src.masonite_permission.mixins import (HasPermissions, HasRoles)
+from src.masonite_permission.mixins import HasPermissions, HasRoles
 
 
 class User(Model, SoftDeletesMixin, Authenticates, HasRoles, HasPermissions):
@@ -11,6 +11,3 @@ class User(Model, SoftDeletesMixin, Authenticates, HasRoles, HasPermissions):
     __fillable__ = ["name", "email", "password"]
     __hidden__ = ["password"]
     __auth__ = "email"
-
-
-    
\ No newline at end of file
